#
# spec file for package embree
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2019-2020 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           embree
Version:        3.8.0
Release:        lp152.1.1
Summary:        Ray Tracing Kernels
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/embree/embree
Source:         https://github.com/%{name}/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 2.8.6
BuildRequires:  gcc-c++
BuildRequires:  memory-constraints
BuildRequires:  pkgconfig
BuildRequires:  tbb-devel
BuildRequires:  pkgconfig(glfw3)
# SSE2 is required: https://github.com/embree/embree/issues/186
ExclusiveArch:  x86_64

%description
Intel Embree is a collection of ray tracing kernels originally developed
at Intel. The target users of Intel Embree are graphics application engineers
who want to improve the performance of their photo-realistic rendering
application by leveraging Embree's ray tracing kernels.

Note:
This version is specifically dedicated to Blender Cycles, as it is using the
build options that are required for it. In order to reduce the risk of
incompatibilities, it is built as static libraries, which is also enforced by
the Blender Cycles build for the time being.

%package	devel-static
Summary:        Development files for embree
Group:          Development/Libraries/C and C++
Provides:       %{name} = %{version}

%description	devel-static
This package contains the C++ header files and static libraries for %{name},
specifically compiled for Blender Cycles needs.

%prep
%setup -q

%build
%limit_build -m 3900
# we need fat lto objects here
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
export CXXFLAGS="%{optflags}"
# blender insists in using static embree
%cmake \
    -DCMAKE_BUILD_TYPE=RelWithDebInfo \
    -DEMBREE_STATIC_LIB=ON \
    -DEMBREE_LIB_INSTALL_DIR=%{_libdir} \
    -DEMBREE_ISPC_SUPPORT=OFF \
    -DEMBREE_TUTORIALS=OFF \
    -DEMBREE_RAY_MASK=ON \
    -DEMBREE_FILTER_FUNCTION=ON \
    -DEMBREE_BACKFACE_CULLING=OFF \
    -DEMBREE_MAX_ISA=AVX2

%make_build

%install
%cmake_install
mv %{buildroot}%{_libdir}/cmake/%{name}-%{version} %{buildroot}%{_libdir}/cmake/%{name}3
rm -r %{buildroot}%{_mandir}
rm -r %{buildroot}/usr/share/doc

%files devel-static
%license LICENSE.txt
%doc CHANGELOG.md README.md
%{_includedir}/embree3
%{_libdir}/cmake/embree3
%{_libdir}/*.a

%changelog
* Wed Feb  5 2020 Hans-Peter Jansen <hpj@urpla.net>
- update to version 3.8.0
  + New Features:
  * Added collision detection support for user geometries (see
    rtcCollide API function)
  * Passing geomID to user geometry callbacks.
  + Fixed Issues:
  * Bugfix in AVX512VL codepath for rtcIntersect1
  * For sphere geometries the intersection filter gets now
    invoked for front and back hit.
  * Fixed some bugs for quaternion motion blur.
  * RTCIntersectContext always non-const in Embree API
  * Made RTCHit aligned to 16 bytes in Embree API
- update to version 3.7.0
  + Added quaternion motion blur for correct interpolation of
    rotational transformations.
  + Fixed wrong bounding calculations when a motion blurred
    instance did instantiate a motion blurred scene.
  + In robust mode the depth test consistently uses tnear <= t <=
    tfar now in order to robustly continue traversal at a previous
    hit point in a way that guarentees reaching all hits, even hits
    at the same place.
  + Fixed depth test in robust mode to be precise at tnear and
    tfar.
  + Added next_hit tutorial to demonstrate robustly collecting all
    hits along a ray using multiple ray queries.
  + Implemented robust mode for curves. This has a small
    performance impact but fixes bounding problems with flat
    curves.
  + Improved quality of motion blur BVH by using linear bounds
    during binning.
  + Implemented issue with motion blur builder where number of time
    segments for SAH heuristic were counted wrong due to some
    numerical issues.
  + Fixed an accuracy issue with rendering very short fat curves.
  + rtcCommitScene can now get called during rendering from
    multiple threads to lazily build geometry. When TBB is used
    this causes a much lower overhead than using
    rtcJoinCommitScene.
  + Geometries can now get attached to multiple scenes at the same
    time, which simplifies mapping general scene graphs to API.
  + Updated to TBB 2019.9 for release builds.
  + Fixed a bug in the BVH builder for Grid geometries.
  + Added macOS Catalina support to Embree releases.
* Fri Oct 11 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.1
  Added Catmull-Rom curve types.
  Added support for multi-level instancing.
  Added support for point queries.
  Fixed a bug preventing normal oriented curves being used unless timesteps were specified.
  Fixed bug in external BVH builder when configured for dynamic build.
  Added support for new config flag "user_threads=N" to device initialization
  which sets the number of threads used by TBB but created by the user.
  Fixed automatic vertex buffer padding when using rtcSetNewGeometry API function.
* Mon Sep  9 2019 Jan Engelhardt <jengelh@inai.de>
- Trim marketing from description.
* Sun Sep  8 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Relax _constraints, and use memory-constraints/limit_build instead
- Disable building for every arch but x86_64, as embree strictly requires
  at least SSE2.
- Use FAT LTO objects in order to provide proper static library.
- Use tbb-devel BuildRequires instead of cmake(TBB), the latter is not
  available in Leap 15.x
* Mon Jul 15 2019 Hans-Peter Jansen <hpj@urpla.net>
- version 3.5.2: initial build
